{% extends "admin_doc/base_docs.html" %}
{% load i18n %}

{% block breadcrumbs %}
<ol class="breadcrumb float-sm-right">
    <li class="breadcrumb-item"><a href="{% url 'admin:index' %}"><i class="fa fa-tachometer-alt"></i> {% trans 'Home' %}</a></li>
    <li class="breadcrumb-item active">{% trans 'Documentation' %}</li>
</ol>
{% endblock %}

{% block title %}{% trans 'Please install docutils' %}{% endblock %}
{% block content_title %}{% trans 'Documentation' %}{% endblock %}

{% block docs_content %}
  <h3>{% blocktrans with "http://docutils.sf.net/" as link %}The admin documentation system requires Python's <a href="{{ link }}">docutils</a> library.{% endblocktrans %}</h3>

  <p>{% blocktrans with "http://docutils.sf.net/" as link %}Please ask your administrators to install <a href="{{ link }}">docutils</a>.{% endblocktrans %}</p>
{% endblock %}
