{% extends "admin/base_site.html" %}

{% block extrastyle %}

<style>
    .literal-block, .doctest-block {
        background: #272822;
        color: #f8f8f2;
    }
    .module {
        padding: 20px;
    }
    .card-header .card-title a {
        color: #ffffff !important;
    }
    .card-header .card-title a:hover {
        color: #f8f8f2 !important;
    }
</style>
{% endblock %}

{% block content %}
{% block alerts %}{% endblock %}
<div id="content-main" class=col-12>
  <div class="col-12">
    <div class="card card-primary card-outline">
      <div class="card-body pad table-responsive">
          {% block docs_content %}{% endblock %}
      </div>
    </div>
  </div>
</div>
{% endblock %}