from __future__ import unicode_literals

from django.apps import AppConfig

__all__ = ["JazzminConfig"]


class JazzminConfig(AppConfig):
    name = "jazzmin"
    label = "jazzmin"
    verbose_name = "Jazzmin"
